[QGIS Commit] r12775 - trunk/qgis/cmake

svn_qgis at osgeo.org svn_qgis at osgeo.org
Sat Jan 16 06:08:04 EST 2010


Author: wonder
Date: 2010-01-16 06:08:04 -0500 (Sat, 16 Jan 2010)
New Revision: 12775

Modified:
   trunk/qgis/cmake/FindSIP.cmake
   trunk/qgis/cmake/SIPMacros.cmake
Log:
Changed SIP_EXECUTABLE to SIP_BINARY_PATH to keep original variable name.


Modified: trunk/qgis/cmake/FindSIP.cmake
===================================================================
--- trunk/qgis/cmake/SIPMacros.cmake	2010-01-16 11:04:41 UTC (rev 12774)
+++ trunk/qgis/cmake/SIPMacros.cmake	2010-01-16 11:08:04 UTC (rev 12775)
@@ -99,7 +99,7 @@
         OUTPUT ${_sip_output_files} 
         COMMAND ${CMAKE_COMMAND} -E echo ${message}
         COMMAND ${TOUCH_COMMAND} ${_sip_output_files} 
-        COMMAND ${SIP_EXECUTABLE} ${_sip_tags} ${_sip_x} ${SIP_EXTRA_OPTIONS} -j ${SIP_CONCAT_PARTS} -c ${CMAKE_CURRENT_BINARY_DIR}/${_module_path} ${_sip_includes} ${_abs_module_sip}
+        COMMAND ${SIP_BINARY_PATH} ${_sip_tags} ${_sip_x} ${SIP_EXTRA_OPTIONS} -j ${SIP_CONCAT_PARTS} -c ${CMAKE_CURRENT_BINARY_DIR}/${_module_path} ${_sip_includes} ${_abs_module_sip}
         DEPENDS ${_abs_module_sip} ${SIP_EXTRA_FILES_DEPEND}
     )
     # not sure if type MODULE could be uses anywhere, limit to cygwin for now



More information about the QGIS-commit mailing list
--- trunk/qgis/cmake/FindSIP.cmake	2010-01-16 11:04:41 UTC (rev 12774)
+++ trunk/qgis/cmake/FindSIP.cmake	2010-01-16 11:08:04 UTC (rev 12775)
@@ -13,7 +13,7 @@
 #
 # SIP_VERSION_STR - The version of SIP found as a human readable string.
 #
 # SIP_EXECUTABLE - Path and filename of the SIP command line executable.
 #
 # SIP_INCLUDE_DIR - Directory holding the SIP C++ header file.
 #
@@ -37,7 +37,7 @@
   IF(sip_config)
     STRING(REGEX REPLACE "^sip_version:([^\n]+).*$" "\\1" SIP_VERSION ${sip_config})
     STRING(REGEX REPLACE ".*\nsip_version_str:([^\n]+).*$" "\\1" SIP_VERSION_STR ${sip_config})
-    STRING(REGEX REPLACE ".*\nsip_bin:([^\n]+).*$" "\\1" SIP_EXECUTABLE ${sip_config})
+    STRING(REGEX REPLACE ".*\nsip_bin:([^\n]+).*$" "\\1" SIP_BINARY_PATH ${sip_config})
     STRING(REGEX REPLACE ".*\ndefault_sip_dir:([^\n]+).*$" "\\1" SIP_DEFAULT_SIP_DIR ${sip_config})
     STRING(REGEX REPLACE ".*\nsip_inc_dir:([^\n]+).*$" "\\1" SIP_INCLUDE_DIR ${sip_config})
     SET(SIP_FOUND TRUE)
@@ -13,7 +13,7 @@
 # SIP_VERSION_STR - The version of SIP found as a human readable string.
 #
-# SIP_EXECUTABLE - Path and filename of the SIP command line executable.
+# SIP_BINARY_PATH - Path and filename of the SIP command line executable.
 #
 # SIP_INCLUDE_DIR - Directory holding the SIP C++ header file.

Modified: trunk/qgis/cmake/SIPMacros.cmake
===================================================================